#!/usr/bin/env python
# -*- coding: utf-8 -*-

from gimpfu import *
from struct import *
import os

def rgbload(filename, raw_filename):
    #:param str filename: ファイルパス
    #:param str raw_filename: 選択ファイル名
    #:rtype: gimp.Image
    #:return: 読み込んだ画像

    path, ext = os.path.splitext(filename)

    dp = open(path+".RGB", 'rb')
    if dp == IOError:
        gimp.message("RGBファイルが開けません")
        return 0
        
    hp = open(path+".IPR", 'rb')
    if hp == IOError:
        gimp.message("IRPファイルが開けません")
        return 0

    head_line = hp.readline()
    head = head_line.split()
    
    width = int(head[0])
    height = int(head[1])


    #GIMPに画像を作成
    image = gimp.Image(width, height, RGB)
    image.filename = filename

    #レイヤー作成
    layer = pdb.gimp_layer_new(image, width, height, RGB, path, 100, NORMAL_MODE )

    image.add_layer(layer, 0)

    #画像展開
    buf = layer.get_pixel_rgn( 0, 0, width, height, True, True )
    
    for y in range(height):
        for x in range(width):
            buf[x,y] = dp.read(3)
	gimp.progress_update(float(y)/float(height)) # プログレスバーの更新

    layer.flush()
    layer.merge_shadow(True)
    layer.update(0, 0, width, height)

    return image

# 登録ハンドラ
def register_load_handlers():
    gimp.register_load_handler('python_fu_RGB_load', 'rgb,ipr', '')
    pdb['gimp-register-file-handler-mime']('python_fu_RGB_load', 'image/xrgb')
#    pdb['gimp-register-thumbnail-loader']('python_fu_RGB_load', '')


register(
    "python_fu_RGB_load", #コマンド名
    "RGB形式ベタ画像を読み込みます", #プロシージャブラウザに表示されるプラグインに関する情報
    "RGB形式ベタ画像を読み込みます", #プラグインのヘルプ
    "Akira M", #プラグインの作成者
    "Akira M", #プラグインの著作権保有者
    "2017", #年
    "RGBベタ", #メニューの中でプラグインに使用されるラベル
    None, #プラグインで処理する対象となる画像のタイプ
    [   #input args. Format (type, name, description, default [, extra])
        (PF_STRING, 'filename', 'The name of the file to load', None),
        (PF_STRING, 'raw-filename', 'The name entered', None),
    ], #プラグインのメソッドのパラメーター
    [(PF_IMAGE, 'image', 'Output image')], #プラグインのメソッドの結果 Format (type, name, description) 
    rgbload,
    on_query = register_load_handlers,
    menu = "<Load>/Load RGB..",
)


main()
